# dist file #

```
# ----------------------------------------------------------------------
#
# jobfile backup.job for scheduling
#
# ----------------------------------------------------------------------
#
# SYNTAX: 
# [variable] = [value]
#
# - variable must start in first column
# - char "=" must be surrounded by space
# - value - any string; no " needed
#
# ----------------------------------------------------------------------

# type = inc
type = auto

lang = en_us

# ----------------------------------------------------------------------
# scheduling for incremental backup and full backup
# for inc and full you can set
#   DOM:06,22        - days of month
#   DOW:Mon,Fri      - weekdays
#   WDM:1st Fri      - nth weekday in month
# ----------------------------------------------------------------------

inc = DOW:Mon,Tue,Wed,Thu,Fri,Sat,Sun

# full backups for type = inc
full = WDM:3rd Fri

# full backups for type = auto
# auto = <time> i.e. 1M 
auto = 1M

# --- when to start every day?

# incremental jobs
#   time HHMM ... multiple values with separated with "," and sorted
#   10:00,12:00,14:00,16:00,18:00
start-time-inc = 20:00
start-time-full = 20:00


# ----------------------------------------------------------------------
# local dumps; each service has its own subdir there
# this entry is mapped to BACKUP_TARGETDIR in "localdump.sh"
# ----------------------------------------------------------------------
dir-localdumps = /var/localdumps/backup
keep-days = 7

# archive databases (to keep deleted schemes or databases that 
# are not backupped anymore; couchdb2 feature)
dir-dbarchive = /var/localdumps/archive

# ----------------------------------------------------------------------
```

# Description #

## auto ##

Define when to make full backups for `type = auto`. It starts incremental backups
only as long the last full backup is not older than the given range.

It is used for Duplicity only and forces the parameter `--full-if-older-than [value]`.

Values are a number followed by a single letter for the time:
s, m, h, D, W, M, or Y (indicating seconds, minutes, hours, days, weeks, months, or years respectively)

`auto = 1M`

## dir-dbarchive ##

Target dir for database archives (to keep deleted schemes or databases that are not backupped anymore; couchdb2 feature)

`dir-dbarchive = /var/localdumps/archive`

## dir-localdumps ##

Target dir for database backups of all types. 
Below that directory a subdir for the database type will be created (i.e. mysql or pgsql).

`dir-localdumps = /var/localdumps/backup`

see also **keep-days**

## keep-days ##

How many days to keep database dumps locally in `dir-localdumps = ...`

`keep-days = 7`

see also **dir-localdumps**

## full ##

Scheduling days for full backup
For inc and full you can set

* day of month: DOM
* weekday: DOW
* nth weekday in a month: WDM

It is followes by a `:` and a single value - or multiple values delimited by `,`.

* Day of month is always a 2 digit value (01..31).
* Keywords for weekdays are Mon, Tue, Wed, Thu, Fri, Sat, Sun.
* Valid numbers of day are 1st, 2nd, 3rd, 4th, 5th followes by space and a weekday

Examples:

* DOM:06,22        - days of month
* DOW:Mon,Fri      - weekdays
* WDM:1st Fri      - nth weekday in month

`full = WDM:3rd Fri`

See also: **inc**, **start-time-full**

## inc ##

Scheduling days for incremental backup.
For valid values see description for **full**

`inc = DOW:Mon,Tue,Wed,Thu,Fri,Sat,Sun`

See also: **full**, **start-time-inc**

## lang ##

Language of the shell. Do not change to keep documented keywords for date and time.

## start-time-full ##

Time when to start an incrmental backup. This value will be handled
if a day matches **full** only.

Values are HHMM ... multiple values with separated with `,` and must be sorted.

If a full time matches an incremental time then full has priority.

`start-time-full= 22:00`

see also **full**

## start-time-inc ##

Time when to start an incrmental backup. This value will be handled
if a day matches **inc** only.

Values are HHMM ... multiple values with separated with `,` and must be sorted

If a full time matches an incremental time then full has priority.

`start-time-inc = 10:00,12:00,14:00,16:00,18:00`

see also **inc**

## type ##

Type of backup.

Restic:

* set to "auto"

Duplicity:

* "inc" - make full and incremental backups defined times. You need more values:
  * full = WDM:3rd Fri
  * inc = DOW:Mon,Tue,Wed,Thu,Fri,Sat,Sun
  * start-time-full = 20:00

* "auto" - starts incremental backups as long last full backup is not older value in
  * auto = 1M

`type = auto`

